/* math.h: Floating-point arithmetic functions. */

#ifndef _MATH_H
#define _MATH_H

typedef float float_t;
typedef double double_t;

#define FP_NAN 0
#define FP_INFINITE 1
#define FP_ZERO 2
#define FP_SUBNORMAL 3
#define FP_NORMAL 4
#define fpclassify(x) __builtin_fpclassify(FP_NAN, FP_INFINITE, FP_ZERO, FP_SUBNORMAL, FP_ZERO, x)

#ifdef __cplusplus
extern "C"
{
#endif

    double cos(double val);
    float cosf(float val);
    long double cosl(long double val);
    double sin(double val);
    float sinf(float val);
    long double sinl(long double val);
    double tan(double val);
    float tanf(float val);
    long double tanl(long double val);
    double acos(double val);
    float acosf(float val);
    long double acosl(long double val);
    double asin(double val);
    float asinf(float val);
    long double asinl(long double val);
    double atan(double val);
    float atanf(float val);
    long double atanl(long double val);
    double cosh(double val);
    float coshf(float val);
    long double coshl(long double val);
    double sinh(double val);
    float sinhf(float val);
    long double sinhl(long double val);
    double tanh(double val);
    float tanhf(float val);
    long double tanhl(long double val);
    double log(double val);
    float logf(float val);
    long double logl(long double val);
    double exp(double val);
    float expf(float val);
    long double expl(long double val);
    double sqrt(double val);
    float sqrtf(float val);
    long double sqrtl(long double val);
    double fabs(double val);
    float fabsf(float val);
    long double fabsl(long double val);
    double floor(double val);
    float floorf(float val);
    long double floorl(long double val);
    double ceil(double val);
    float ceilf(float val);
    long double ceill(long double val);
    double log10(double val);
    float log10f(float val);
    long double log10l(long double val);
    double fmod(double val1, double val2);
    float fmodf(float val1, float val2);
    long double fmodl(long double val1, long double val2);
    double pow(double val1, double val2);
    float powf(float val1, float val2);
    long double powl(long double val1, long double val2);
    double atan2(double val1, double val2);
    float atan2f(float val1, float val2);
    long double atan2l(long double val1, long double val2);
    double frexp(double val1, int* val2);
    float frexpf(float val1, int* val2);
    long double frexpl(long double val1, int* val2);
    double ldexp(double val1, int val2);
    float ldexpf(float val1, int val2);
    long double ldexpl(long double val1, int val2);
    double modf(double val1, double* val2);
    float modff(float val1, float* val2);
    long double modfl(long double val1, long double* val2);

#ifdef __cplusplus
}
#endif

#endif
